@@ -1,7 +1,4 @@
-from astropy import units
-from astropy.coordinates import EarthLocation
-from astropy.tests.helper import assert_quantity_allclose
-from numpy.testing import assert_array_equal
+from numpy.testing import assert_array_almost_equal, assert_array_equal
 
 
 def assert_earth_location_equal(a, b):
@@ -11,6 +8,8 @@ def assert_earth_location_equal(a, b):
 
 
 def assert_representation_equal(a, b):
+    from astropy import units
+
     __tracebackhide__ = True
 
     assert type(a) is type(b)
@@ -37,10 +36,16 @@ def assert_frame_equal(a, b):
     if a is None:
         return
 
-    assert_representation_equal(a.data, b.data)
+    if a.has_data:
+        assert b.has_data
+        assert_representation_equal(a.data, b.data)
+    else:
+        return
 
 
 def assert_spectral_coord_equal(a, b):
+    from astropy.tests.helper import assert_quantity_allclose
+
     __tracebackhide__ = True
 
     assert type(a) is type(b)
@@ -50,6 +55,8 @@ def assert_spectral_coord_equal(a, b):
 
 
 def assert_time_equal(a, b):
+    from astropy.coordinates import EarthLocation
+
     assert a.format == b.format
     assert a.scale == b.scale
 
@@ -59,7 +66,10 @@ def assert_time_equal(a, b):
     else:
         assert a.location == b.location
 
-    assert_array_equal(a, b)
+    if a.format == "plot_date":
+        assert_array_almost_equal(a.value, b.value)
+    else:
+        assert_array_equal(a, b)
 
 
 def assert_time_delta_equal(a, b):
@@ -95,6 +105,7 @@ def assert_model_equal(a, b):
 
     assert_array_equal(a.parameters, b.parameters)
 
+    assert a._user_bounding_box == b._user_bounding_box
     try:
         a_bounding_box = a.bounding_box
     except NotImplementedError:
